@@ -13,6 +13,7 @@ from qtpy.QtCore import Qt
 from glue.core.application_base import Application
 from glue.core.message import ApplicationClosedMessage
 from glue.core import command, Data
+from glue.core.coordinates import WCSCoordinates
 from glue import env
 from glue.main import load_plugins
 from glue.icons.qt import get_icon
@@ -21,7 +22,7 @@ from glue.app.qt.actions import action
 from glue.dialogs.data_wizard.qt import data_wizard
 from glue.dialogs.link_editor.qt import LinkEditor
 from glue.app.qt.edit_subset_mode_toolbar import EditSubsetModeToolBar
-from glue.app.qt.mdi_area import GlueMdiArea, GlueMdiSubWindow
+from glue.app.qt.mdi_area import GlueMdiArea
 from glue.app.qt.layer_tree_widget import PlotAction, LayerTreeWidget
 from glue.app.qt.preferences import PreferencesDialog
 from glue.viewers.common.qt.data_viewer import DataViewer
@@ -33,9 +34,9 @@ from glue.utils.qt import (pick_class, GlueTabBar,
 
 from glue.app.qt.feedback import submit_bug_report, submit_feedback
 from glue.app.qt.plugin_manager import QtPluginManager
-from glue.app.qt.versions import show_glue_info
+from glue.app.qt.versions import QVersionsDialog
 from glue.app.qt.terminal import glue_terminal, IPythonTerminalError
-
+from glue.config import qt_fixed_layout_tab, qt_client, startup_action
 
 __all__ = ['GlueApplication']
 DOCS_URL = 'http://www.glueviz.org'
@@ -188,13 +189,22 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
 
     def __init__(self, data_collection=None, session=None):
 
+        # At this point we need to check if a Qt application already exists -
+        # this happens for example if using the %gui qt/qt5 mode in Jupyter. We
+        # should keep a reference to the original icon so that we can restore it
+        # later
+        self._original_app = QtWidgets.QApplication.instance()
+        if self._original_app is not None:
+            self._original_icon = self._original_app.windowIcon()
+
+        # Now we can get the application instance, which involves setting it
+        # up if it doesn't already exist.
         self.app = get_qapp()
 
         QtWidgets.QMainWindow.__init__(self)
         Application.__init__(self, data_collection=data_collection,
                              session=session)
 
-        self.app.setQuitOnLastWindowClosed(True)
         icon = get_icon('app_icon')
         self.app.setWindowIcon(icon)
 
@@ -228,6 +238,12 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         self.new_tab()
         self._update_plot_dashboard(None)
 
+    def run_startup_action(self, name):
+        if name in startup_action.members:
+            startup_action.members[name](self.session, self.data_collection)
+        else:
+            raise Exception("Unknown startup action: {0}".format(name))
+
     def _setup_ui(self):
         self._ui = load_ui('application.ui', None,
                            directory=os.path.dirname(__file__))
@@ -368,6 +384,12 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
     def current_tab(self):
         return self._ui.tabWidget.currentWidget()
 
+    def get_tab_index(self, widget):
+        for idx in range(self.tab_count):
+            if self.tab(idx) == widget:
+                return idx
+        raise Exception("Tab not found")
+
     def tab(self, index=None):
         if index is None:
             return self.current_tab
@@ -386,14 +408,14 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         tab.setCurrentWidget(widget)
         widget.subWindowActivated.connect(self._update_plot_dashboard)
 
-    def close_tab(self, index):
+    def close_tab(self, index, warn=True):
         """ Close a tab window and all associated data viewers """
 
         # do not delete the last tab
         if self.tab_widget.count() == 1:
             return
 
-        if not os.environ.get('GLUE_TESTING'):
+        if warn and not os.environ.get('GLUE_TESTING'):
             buttons = QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
             dialog = QtWidgets.QMessageBox.warning(
                 self, "Confirm Close",
@@ -434,6 +456,20 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
                               of new_widget
         :type hold_position: bool
         """
+
+        # Find first tab that supports addSubWindow
+        if tab is None:
+            if hasattr(self.current_tab, 'addSubWindow'):
+                pass
+            else:
+                for tab in range(self.tab_count):
+                    page = self.tab(tab)
+                    if hasattr(page, 'addSubWindow'):
+                        break
+                else:
+                    self.new_tab()
+                    tab = self.tab_count - 1
+
         page = self.tab(tab)
         pos = getattr(new_widget, 'position', None)
         sub = new_widget.mdi_wrap()
@@ -446,10 +482,13 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         page.setActiveSubWindow(sub)
         if hold_position and pos is not None:
             new_widget.move(pos[0], pos[1])
+
+        self.tab_widget.setCurrentWidget(page)
+
         return sub
 
     def _edit_settings(self):
-        self._editor = PreferencesDialog(self)
+        self._editor = PreferencesDialog(self, parent=self)
         self._editor.show()
 
     def gather_current_tab(self):
@@ -458,10 +497,8 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
 
     def _get_plot_dashboards(self, sub_window):
 
-        if not isinstance(sub_window, GlueMdiSubWindow):
-            return QtWidgets.QWidget(), QtWidgets.QWidget(), ""
-
         widget = sub_window.widget()
+
         if not isinstance(widget, DataViewer):
             return QtWidgets.QWidget(), QtWidgets.QWidget(), ""
 
@@ -547,7 +584,13 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
                 submenu.addAction(a)
         menu.addSeparator()
         menu.addAction("Edit &Preferences", self._edit_settings)
-        menu.addAction("&Quit", self.app.quit)
+        # Here we use close instead of self.app.quit because if we are launching
+        # glue from an environment with a Qt event loop already existing, we
+        # don't want to quit this. Using close here is safer, though it does
+        # mean that any dialog we launch from glue has to be either modal (to
+        # prevent quitting) or correctly define its parent so that it gets
+        # closed too.
+        menu.addAction("&Quit", self.close)
         mbar.addMenu(menu)
 
         menu = QtWidgets.QMenu(mbar)
@@ -568,6 +611,7 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         menu.setTitle("&Canvas")
         menu.addAction(self._actions['tab_new'])
         menu.addAction(self._actions['viewer_new'])
+        menu.addAction(self._actions['fixed_layout_tab_new'])
         menu.addSeparator()
         menu.addAction(self._actions['gather'])
         menu.addAction(self._actions['tab_rename'])
@@ -602,7 +646,12 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         menu.addAction(a)
 
         menu.addSeparator()
-        menu.addAction("Version information", show_glue_info)
+        menu.addAction("Version information", self._show_glue_info)
+
+    def _show_glue_info(self):
+        window = QVersionsDialog(parent=self)
+        window.show()
+        window.exec_()
 
     def _choose_load_data(self, data_importer=None):
         if data_importer is None:
@@ -628,6 +677,17 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         a.triggered.connect(nonpartial(self.choose_new_data_viewer))
         self._actions['viewer_new'] = a
 
+        if len(qt_client.members) == 0:
+            a.setEnabled(False)
+
+        a = action("New Fixed Layout Tab", self,
+                   tip="Create a new tab with a fixed layout")
+        a.triggered.connect(nonpartial(self.choose_new_fixed_layout_tab))
+        self._actions['fixed_layout_tab_new'] = a
+
+        if len(qt_fixed_layout_tab.members) == 0:
+            a.setEnabled(False)
+
         a = action('New &Tab', self,
                    shortcut=QtGui.QKeySequence.AddTab,
                    tip='Add a new tab')
@@ -637,7 +697,7 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         a = action('&Rename Tab', self,
                    shortcut="Ctrl+R",
                    tip='Set a new label for the current tab')
-        a.triggered.connect(nonpartial(self.tab_bar.rename_tab))
+        a.triggered.connect(nonpartial(self.tab_bar.choose_rename_tab))
         self._actions['tab_rename'] = a
 
         a = action('&Gather Windows', self,
@@ -733,12 +793,36 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         a.triggered.connect(nonpartial(self.plugin_manager))
         self._actions['plugin_manager'] = a
 
+    def choose_new_fixed_layout_tab(self):
+        """
+        Creates a new tab with a fixed layout
+        """
+
+        tab_cls = pick_class(list(qt_fixed_layout_tab.members), title='Fixed layout tab',
+                             label="Choose a new fixed layout tab",
+                             sort=True)
+
+        return self.add_fixed_layout_tab(tab_cls)
+
+    def add_fixed_layout_tab(self, tab_cls):
+
+        tab = tab_cls(session=self.session)
+
+        self._total_tab_count += 1
+
+        name = 'Tab {0}'.format(self._total_tab_count)
+        if hasattr(tab, 'LABEL'):
+            name += ': ' + tab.LABEL
+        self.tab_widget.addTab(tab, name)
+        self.tab_widget.setCurrentWidget(tab)
+        tab.subWindowActivated.connect(self._update_plot_dashboard)
+
+        return tab
+
     def choose_new_data_viewer(self, data=None):
         """ Create a new visualization window in the current tab
         """
 
-        from glue.config import qt_client
-
         if data and data.ndim == 1 and ScatterViewer in qt_client.members:
             default = ScatterViewer
         elif data and data.ndim > 1 and ImageViewer in qt_client.members:
@@ -805,17 +889,23 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         if not file_name:
             return
 
-        with set_cursor_cm(Qt.WaitCursor):
-            ga = self.restore_session(file_name)
-            self.close()
+        ga = self.restore_session_and_close(file_name)
         return ga
 
+    @property
+    def is_empty(self):
+        """
+        Returns `True` if there are no viewers and no data.
+        """
+        return (len([viewer for tab in self.viewers for viewer in tab]) == 0 and
+                len(self.data_collection) == 0)
+
     def _reset_session(self, show=True, warn=True):
         """
         Reset session to clean state.
         """
 
-        if not os.environ.get('GLUE_TESTING') and warn:
+        if not os.environ.get('GLUE_TESTING') and warn and not self.is_empty:
             buttons = QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
             dialog = QtWidgets.QMessageBox.warning(
                 self, "Confirm Close",
@@ -888,6 +978,8 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
             self._hide_terminal()
 
     def _toggle_terminal(self):
+        if self._terminal is None:
+            self._create_terminal()
         if self._terminal.isVisible():
             self._hide_terminal()
             if self._terminal.isVisible():
@@ -924,7 +1016,6 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         position : (int, int) Optional
             The default position of the application
         """
-        self._create_terminal()
         if maximized:
             self.showMaximized()
         else:
@@ -968,9 +1059,31 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
                 if path.startswith('/') and path[2] == ':':
                     path = path[1:]
 
-            self.load_data(path)
+            if path.endswith('.glu'):
+                self.restore_session_and_close(path)
+            else:
+                self.load_data(path)
+
         event.accept()
 
+    @messagebox_on_error("Failed to restore session")
+    def restore_session_and_close(self, path, warn=True):
+
+        if warn and not self.is_empty:
+            buttons = QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel
+            dialog = QtWidgets.QMessageBox.warning(
+                self, "Confirm Close",
+                "Loading a session file will close the existing session. Are you "
+                "sure you want to continue?",
+                buttons=buttons, defaultButton=QtWidgets.QMessageBox.Cancel)
+            if not dialog == QtWidgets.QMessageBox.Ok:
+                return
+
+        with set_cursor_cm(Qt.WaitCursor):
+            app = self.restore_session(path)
+            app.setGeometry(self.geometry())
+            self.close()
+
     def closeEvent(self, event):
         """Emit a message to hub before closing."""
         for tab in self.viewers:
@@ -979,6 +1092,8 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         self._log.close()
         self._hub.broadcast(ApplicationClosedMessage(None))
         event.accept()
+        if self._original_app is not None:
+            self._original_app.setWindowIcon(self._original_icon)
 
     def report_error(self, message, detail):
         """
@@ -1053,6 +1168,13 @@ class GlueApplication(Application, QtWidgets.QMainWindow):
         # least one new one, have a common shape.
         others.append(data)
         others.sort(key=lambda x: x.label)
+        for i, d in enumerate(others):
+            if isinstance(d.coords, WCSCoordinates):
+                if i == 0:
+                    break
+                else:
+                    others[0], others[i] = others[i], others[0]
+                    break
 
         label = others[0].label
         w.merged_label.setText(label)
