@@ -6,7 +6,7 @@ from qtpy import QtWidgets
 
 from glue.external.echo.qt import autoconnect_callbacks_to_qt
 from glue.utils import nonpartial
-from glue.utils.qt import load_ui
+from glue.utils.qt import load_ui, fix_tab_widget_fontsize
 
 __all__ = ['HistogramOptionsWidget']
 
@@ -20,6 +20,8 @@ class HistogramOptionsWidget(QtWidgets.QWidget):
         self.ui = load_ui('options_widget.ui', self,
                           directory=os.path.dirname(__file__))
 
+        fix_tab_widget_fontsize(self.ui.tab_widget)
+
         autoconnect_callbacks_to_qt(viewer_state, self.ui)
 
         self.viewer_state = viewer_state
@@ -30,5 +32,7 @@ class HistogramOptionsWidget(QtWidgets.QWidget):
         # If at least one of the components is categorical, disable log button
         log_enabled = not any(comp.categorical for comp in self.viewer_state._get_x_components())
         self.ui.bool_x_log.setEnabled(log_enabled)
+        self.ui.bool_x_log_.setEnabled(log_enabled)
         if not log_enabled:
             self.ui.bool_x_log.setChecked(False)
+            self.ui.bool_x_log_.setChecked(False)
