@@ -5,7 +5,7 @@ import os
 from qtpy import QtWidgets
 
 from glue.external.echo.qt import autoconnect_callbacks_to_qt
-from glue.utils.qt import load_ui
+from glue.utils.qt import load_ui, fix_tab_widget_fontsize
 from glue.viewers.image.qt.slice_widget import MultiSliceWidgetHelper
 
 __all__ = ['ImageOptionsWidget']
@@ -20,6 +20,8 @@ class ImageOptionsWidget(QtWidgets.QWidget):
         self.ui = load_ui('options_widget.ui', self,
                           directory=os.path.dirname(__file__))
 
+        fix_tab_widget_fontsize(self.ui.tab_widget)
+
         self.ui.combodata_aspect.addItem("Square Pixels", userData='equal')
         self.ui.combodata_aspect.addItem("Automatic", userData='auto')
         self.ui.combodata_aspect.setCurrentIndex(0)
