@@ -162,7 +162,7 @@ class TestImageViewer(object):
         assert self.viewer.state.y_att_world is self.image1.id['World 0']
         # TODO: there should be an easier way to do this
         layer_style_editor = self.viewer._view.layout_style_widgets[self.viewer.layers[0]]
-        assert combo_as_string(layer_style_editor.ui.combodata_attribute) == 'x:y:z'
+        assert combo_as_string(layer_style_editor.ui.combosel_attribute) == 'x:y:z'
 
     def test_apply_roi(self):
 
@@ -182,6 +182,12 @@ class TestImageViewer(object):
         state = self.image1.subsets[0].subset_state
         assert isinstance(state, RoiSubsetState)
 
+    def test_apply_roi_empty(self):
+        # Make sure that doing an ROI selection on an empty viewer doesn't
+        # produce error messsages
+        roi = XRangeROI(-0.2, 0.1)
+        self.viewer.apply_roi(roi)
+
     def test_identical(self):
 
         # Check what happens if we set both attributes to the same coordinates
@@ -516,6 +522,64 @@ class TestImageViewer(object):
         # Removing the subset should bring the count back to 1 again
         assert len(get_modest_images()) == 1
 
+    def test_select_previously_incompatible_layer(self):
+
+        # Regression test for a bug that caused a selection in a previously disabled
+        # layer to enable the layer without updating the subset view
+
+        self.viewer.add_data(self.image1)
+        self.viewer.add_data(self.catalog)
+        self.catalog.add_component([4, 5, 6], 'e')
+
+        link1 = LinkSame(self.catalog.id['c'], self.image1.world_component_ids[0])
+        link2 = LinkSame(self.catalog.id['d'], self.image1.world_component_ids[1])
+        self.data_collection.add_link(link1)
+        self.data_collection.add_link(link2)
+
+        self.data_collection.new_subset_group(subset_state=self.catalog.id['e'] > 4)
+
+        assert self.viewer.layers[0].enabled  # image
+        assert self.viewer.layers[1].enabled  # scatter
+        assert not self.viewer.layers[2].enabled  # image subset
+        assert self.viewer.layers[3].enabled  # scatter subset
+
+        assert not self.viewer.layers[2].image_artist.get_visible()
+
+        self.data_collection.subset_groups[0].subset_state = self.catalog.id['c'] > -1
+
+        assert self.viewer.layers[0].enabled  # image
+        assert self.viewer.layers[1].enabled  # scatter
+        assert self.viewer.layers[2].enabled  # image subset
+        assert self.viewer.layers[3].enabled  # scatter subset
+
+        assert self.viewer.layers[2].image_artist.get_visible()
+
+    def test_linking_and_enabling(self):
+
+        # Regression test for a bug that caused layers not not be correctly
+        # enabled/disabled.
+
+        self.viewer.add_data(self.image1)
+        self.viewer.add_data(self.catalog)
+        self.catalog.add_component([4, 5, 6], 'e')
+
+        self.data_collection.new_subset_group(subset_state=self.catalog.id['e'] > 4)
+
+        assert self.viewer.layers[0].enabled  # image
+        assert not self.viewer.layers[1].enabled  # scatter
+        assert not self.viewer.layers[2].enabled  # image subset
+        assert not self.viewer.layers[3].enabled  # scatter subset
+
+        link1 = LinkSame(self.catalog.id['c'], self.image1.world_component_ids[0])
+        link2 = LinkSame(self.catalog.id['d'], self.image1.world_component_ids[1])
+        self.data_collection.add_link(link1)
+        self.data_collection.add_link(link2)
+
+        assert self.viewer.layers[0].enabled  # image
+        assert self.viewer.layers[1].enabled  # scatter
+        assert not self.viewer.layers[2].enabled  # image subset
+        assert self.viewer.layers[3].enabled  # scatter subset
+
 
 class TestSessions(object):
 
