@@ -87,6 +87,20 @@ class ImageViewerState(MatplotlibDataViewerState):
 
         self.update_from_dict(kwargs)
 
+    def reset_limits(self):
+
+        if self.reference_data is None or self.x_att is None or self.y_att is None:
+            return
+
+        nx = self.reference_data.shape[self.x_att.axis]
+        ny = self.reference_data.shape[self.y_att.axis]
+
+        with delay_callback(self, 'x_min', 'x_max', 'y_min', 'y_max'):
+            self.x_min = -0.5
+            self.x_max = nx - 0.5
+            self.y_min = -0.5
+            self.y_max = ny - 0.5
+
     def _reference_data_changed(self, *args):
         with delay_callback(self, 'x_att_world', 'y_att_world', 'slices'):
             self._update_combo_att()
@@ -124,7 +138,9 @@ class ImageViewerState(MatplotlibDataViewerState):
         for data, layer_states in layer_state_by_data.items():
             if len(layer_states) > 1:
                 for layer_state in layer_states:
-                    if layer_state.global_sync:
+                    # Scatter layers don't have global_sync so we need to be
+                    # careful here and make sure we return a default value
+                    if getattr(layer_state, 'global_sync', False):
                         layer_state.global_sync = False
 
     def _update_combo_ref_data(self):
@@ -340,18 +356,18 @@ class ImageLayerState(BaseImageLayerState):
     A state class that includes all the attributes for data layers in an image plot.
     """
 
-    attribute = DDCProperty(docstring='The attribute shown in the layer')
+    attribute = DDSCProperty(docstring='The attribute shown in the layer')
     v_min = DDCProperty(docstring='The lower level shown')
     v_max = DDCProperty(docstring='The upper leven shown')
-    percentile = DDCProperty(100, docstring='The percentile value used to '
-                                            'automatically calculate levels')
+    percentile = DDSCProperty(docstring='The percentile value used to '
+                                        'automatically calculate levels')
     contrast = DDCProperty(1, docstring='The contrast of the layer')
     bias = DDCProperty(0.5, docstring='A constant value that is added to the '
                                       'layer before rendering')
     cmap = DDCProperty(docstring='The colormap used to render the layer')
-    stretch = DDCProperty('linear', docstring='The stretch used to render the layer, '
-                                              'which should be one of ``linear``, '
-                                              '``sqrt``, ``log``, or ``arcsinh``')
+    stretch = DDSCProperty(docstring='The stretch used to render the layer, '
+                                     'which should be one of ``linear``, '
+                                     '``sqrt``, ``log``, or ``arcsinh``')
     global_sync = DDCProperty(True, docstring='Whether the color and transparency '
                                               'should be synced with the global '
                                               'color and transparency for the data')
@@ -360,9 +376,30 @@ class ImageLayerState(BaseImageLayerState):
 
         super(ImageLayerState, self).__init__(layer=layer, viewer_state=viewer_state)
 
-        self.attribute_helper = StateAttributeLimitsHelper(self, attribute='attribute',
-                                                           percentile='percentile',
-                                                           lower='v_min', upper='v_max')
+        self.attribute_lim_helper = StateAttributeLimitsHelper(self, attribute='attribute',
+                                                               percentile='percentile',
+                                                               lower='v_min', upper='v_max')
+
+        self.attribute_att_helper = ComponentIDComboHelper(self, 'attribute',
+                                                           numeric=True, categorical=False)
+
+        percentile_display = {100: 'Min/Max',
+                              99.5: '99.5%',
+                              99: '99%',
+                              95: '95%',
+                              90: '90%',
+                              'Custom': 'Custom'}
+
+        ImageLayerState.percentile.set_choices(self, [100, 99.5, 99, 95, 90, 'Custom'])
+        ImageLayerState.percentile.set_display_func(self, percentile_display.get)
+
+        stretch_display = {'linear': 'Linear',
+                           'sqrt': 'Square Root',
+                           'arcsinh': 'Arcsinh',
+                           'log': 'Logarithmic'}
+
+        ImageLayerState.stretch.set_choices(self, ['linear', 'sqrt', 'arcsinh', 'log'])
+        ImageLayerState.stretch.set_display_func(self, stretch_display.get)
 
         self.add_callback('global_sync', self._update_syncing)
         self.add_callback('layer', self._update_attribute)
@@ -379,6 +416,7 @@ class ImageLayerState(BaseImageLayerState):
 
     def _update_attribute(self, *args):
         if self.layer is not None:
+            self.attribute_att_helper.set_multiple_data([self.layer])
             self.attribute = self.layer.visible_components[0]
 
     def _update_priority(self, name):
@@ -408,7 +446,7 @@ class ImageLayerState(BaseImageLayerState):
         """
         Flip the image levels.
         """
-        self.attribute_helper.flip_limits()
+        self.attribute_lim_helper.flip_limits()
 
     def reset_contrast_bias(self):
         with delay_callback(self, 'contrast', 'bias'):
