@@ -5,7 +5,7 @@ import os
 from qtpy import QtWidgets
 
 from glue.external.echo.qt import autoconnect_callbacks_to_qt
-from glue.utils.qt import load_ui
+from glue.utils.qt import load_ui, fix_tab_widget_fontsize
 
 __all__ = ['ScatterOptionsWidget']
 
@@ -19,9 +19,6 @@ class ScatterOptionsWidget(QtWidgets.QWidget):
         self.ui = load_ui('options_widget.ui', self,
                           directory=os.path.dirname(__file__))
 
+        fix_tab_widget_fontsize(self.ui.tab_widget)
+
         autoconnect_callbacks_to_qt(viewer_state, self.ui)
-
-        self.viewer_state = viewer_state
-
-    def reset_limits(self):
-        self.viewer_state.reset_limits()
